package l04_classes;

public enum Planet {

	MERCURY (3.303e+23, 2.4397e6),
	VENUS   (4.869e+24, 6.0518e6),
	EARTH   (5.976e+24, 6.37814e6),
	MARS    (6.421e+23, 3.3972e6),
	JUPITER (1.900e+27, 7.1492e7),
	SATURN  (5.688e+26, 6.0268e7),
	URANUS  (8.686e+25, 2.5559e7),
	NEPTUNE (1.024e+26, 2.4746e7);

	private final double mass;		//	in kilograms
	private final double radius;	//	in meters

	Planet(double mass, double radius) { // private by default
		this.mass = mass;
		this.radius = radius;
	}

	//	universal gravitational constant (m3 kg-1 s-2)
	private static final double G = 6.67300E-11;

	private double surfaceGravity() {
		return G * mass / (radius * radius);
	}

	private double surfaceWeight(double otherMass) {
		return otherMass * surfaceGravity();
	}

	public static void main(String[] args) {
		double earthWeight = (args.length < 1) ? 50 : Double.parseDouble(args[0]);
		double mass = earthWeight / EARTH.surfaceGravity();
		for (Planet p : Planet.values()) { // list of enumerated constants
			System.out.printf("Your weight on %s is %.2f%n", p, p.surfaceWeight(mass)); // toString()
		}
	}
}

