package l04_classes;

// A Java Record is a special kind of Java class which has a concise syntax
// for defining immutable data-only classes.

// Available since Java 16 (since Java 14 as preview feature)

// From Oracle documentation:
// While it is superficially tempting to treat records as primarily being about
// boilerplate reduction, we instead choose a more semantic goal: modeling
// data as data. It should be easy, clear, and concise to declare shallowly-immutable,
// well-behaved nominal data aggregates.

// A Java Record consist of one or more data fields which corresponds to member
// variables in a regular Java class. The Java compiler auto generates getter
// methods, toString(), hashcode() and equals() methods for these data fields,
// so you don't have to write that boilerplate code yourself.
// Since a Java Record is immutable, no setter methods are generated.

public record Student (String firstName, String lastName, int id) {

    // Not necessary; just for aesthetic reasons
    @Override
    public String toString() {
        return String.format("%d: %s %s", id, firstName, lastName);
    }
}

